@@ -1,4 +1,5 @@
 library(testthat)
-library(breathteststan)
 Sys.unsetenv("R_TESTS") # https://github.com/r-lib/testthat/issues/603
+options(Ncpus = parallelly::availableCores(omit = 1))
+
 test_check("breathteststan")
